@@ -18,6 +18,16 @@
  * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
+/**
+ * SECTION:gv-engine
+ * @title: GvEngine
+ * @short_description: The engine, where Goodvibes meets GStreamer
+ *
+ * Documentation of interest for this part:
+ * - https://gstreamer.freedesktop.org/documentation/application-development/advanced/buffering.html
+ * - https://gstreamer.freedesktop.org/documentation/tutorials/basic/streaming.html
+ */
+
 #include <glib-object.h>
 #include <glib.h>
 #include <gst/audio/streamvolume.h>
@@ -38,9 +48,11 @@
 /* Uncomment to dump more stuff from GStreamer */
 
 //#define DEBUG_GST_TAGS
-//#define DEBUG_GST_STATE_CHANGES
 //#define DEBUG_GST_ELEMENT_SETUP
 
+/* Whether we prefer to ignore buffering messages while playing */
+#define IGNORE_BUFFERING_MESSAGES
+
 /*
  * Properties
  */
@@ -86,6 +98,11 @@ struct _GvEnginePrivate {
 	/* GStreamer stuff */
 	GstElement *playbin;
 	GstBus *bus;
+	/* Playbin state */
+	gboolean buffering;
+	GstState target_state;
+	guint retry_count;
+	guint retry_timeout_id;
 	/* Properties */
 	GvEngineState state;
 	GvStation *station;
@@ -95,9 +112,6 @@ struct _GvEnginePrivate {
 	gboolean mute;
 	gboolean pipeline_enabled;
 	gchar *pipeline_string;
-	/* Retry on error with a delay */
-	guint error_count;
-	guint start_playback_timeout_id;
 };
 
 typedef struct _GvEnginePrivate GvEnginePrivate;
@@ -120,29 +134,31 @@ G_DEFINE_TYPE_WITH_CODE(GvEngine, gv_engine, G_TYPE_OBJECT,
 static void
 set_gst_state(GstElement *playbin, GstState state)
 {
-	const gchar *state_name = gst_element_state_get_name(state);
-	GstStateChangeReturn change_return;
+	gboolean expect_success;
+	GstStateChangeReturn ret;
+	const gchar *state_name;
+	const gchar *return_name;
 
-	change_return = gst_element_set_state(playbin, state);
+	/* Based on the documentation of GstElement [1]:
+	 *
+	 *   State changes to GST_STATE_READY or GST_STATE_NULL never return
+	 *   GST_STATE_CHANGE_ASYNC.
+	 *
+	 * [1]: https://gstreamer.freedesktop.org/documentation/gstreamer/gstelement.html
+	 *      #gst_element_set_state
+	 */
+	expect_success = state <= GST_STATE_READY ? TRUE : FALSE;
 
-	switch (change_return) {
-	case GST_STATE_CHANGE_SUCCESS:
-		DEBUG("Setting gst state '%s'... success", state_name);
-		break;
-	case GST_STATE_CHANGE_ASYNC:
-		DEBUG("Setting gst state '%s'... will change async", state_name);
-		break;
-	case GST_STATE_CHANGE_FAILURE:
-		/* This might happen if the uri is invalid */
-		DEBUG("Setting gst state '%s'... failed!", state_name);
-		break;
-	case GST_STATE_CHANGE_NO_PREROLL:
-		DEBUG("Setting gst state '%s'... no preroll", state_name);
-		break;
-	default:
-		WARNING("Unhandled state change: %d", change_return);
-		break;
-	}
+	ret = gst_element_set_state(playbin, state);
+	state_name = gst_element_state_get_name(state);
+	return_name = gst_element_state_change_return_get_name(ret);
+
+	if (ret == GST_STATE_CHANGE_FAILURE)
+		WARNING("Failed to set playbin state to %s", state_name);
+	else if (ret != GST_STATE_CHANGE_SUCCESS && expect_success == TRUE)
+		WARNING("Set playbin state to %s, got unexpected %s", state_name, return_name);
+	else
+		DEBUG("Set playbin state to %s, got %s", state_name, return_name);
 }
 
 #if 0
@@ -548,6 +564,120 @@ gv_engine_set_property(GObject *object,
 	}
 }
 
+/*
+ * Private methods
+ */
+
+static void
+_stop_playback(GvEngine *self, gboolean reset_retry)
+{
+	GvEnginePrivate *priv = self->priv;
+	GstElement *playbin = priv->playbin;
+
+	/* To stop the playback, we can set it to either READY or NULL. The
+	 * difference is that when we set it to READY, we'll receive a bunch of
+	 * "state-changed" message, that we can use to update our own state.
+	 * While if we set it to NULL, we won't receive any "state-changed"
+	 * message, therefore we need to update our state manually.
+	 *
+	 * We go for the latter, as it's what has always been done in Goodvibes
+	 * so far, and it's also a sure guarantee that will receive a
+	 * "state-changed=ready" message when we'll want to start the playback
+	 * (since we'll go from NULL to READY).
+	 */
+
+	if (reset_retry == TRUE) {
+		priv->retry_count = 0;
+		g_clear_handle_id(&priv->retry_timeout_id, g_source_remove);
+	}
+	priv->buffering = FALSE;
+	priv->target_state = GST_STATE_NULL;
+	set_gst_state(playbin, GST_STATE_NULL);
+	gv_engine_set_state(self, GV_ENGINE_STATE_STOPPED);
+}
+
+#define stop_playback(self) _stop_playback(self, TRUE)
+
+static void
+_start_playback(GvEngine *self, gboolean force_stop)
+{
+	GvEnginePrivate *priv = self->priv;
+	GstElement *playbin = priv->playbin;
+
+	/* First, stop the playback, in case it's not stopped already. Then set
+	 * the playbin state to PAUSED, so that it starts buffering data.  When
+	 * buffering reaches 100%, we'll start playing for real. This is
+	 * handled in the callback for buffering messages.
+	 *
+	 * It's also possible that there's no buffering, and this is handled
+	 * in the callback for state-changed messages.
+	 */
+
+	if (force_stop == TRUE)
+		_stop_playback(self, TRUE);
+	priv->target_state = GST_STATE_PAUSED;
+	set_gst_state(playbin, GST_STATE_PAUSED);
+}
+
+#define start_playback(self) _start_playback(self, TRUE)
+
+static void
+start_playback_for_real(GvEngine *self)
+{
+	GvEnginePrivate *priv = self->priv;
+	GstElement *playbin = priv->playbin;
+
+	priv->target_state = GST_STATE_PLAYING;
+	set_gst_state(playbin, GST_STATE_PLAYING);
+}
+
+static gboolean
+when_timeout_retry(gpointer data)
+{
+	GvEngine *self = GV_ENGINE(data);
+	GvEnginePrivate *priv = self->priv;
+
+	/* Make sure we still want to play. Then play in a "special way",
+	 * as we don't want to touch the retry counter.
+	 */
+	if (priv->target_state >= GST_STATE_PAUSED) {
+		_stop_playback(self, FALSE);
+		_start_playback(self, FALSE);
+	}
+
+	priv->retry_timeout_id = 0;
+	return G_SOURCE_REMOVE;
+}
+
+static void
+retry_playback(GvEngine *self)
+{
+	GvEnginePrivate *priv = self->priv;
+	guint delay;
+
+	/* We retry playback after there's been a failure of some sort.
+	 * We don't know what kind of failure, and maybe the network is down,
+	 * in such case we don't want to keep retrying in a wild loop.
+	 * So we schedule the retry, and increase the delay each time.
+	 */
+
+	/* If retry was already scheduled, bail out */
+	if (priv->retry_timeout_id != 0)
+		return;
+
+	/* Stop playback now to stop gst from retrying */
+	set_gst_state(priv->playbin, GST_STATE_NULL);
+
+	/* Increase retry count */
+	priv->retry_count++;
+	delay = priv->retry_count - 1;
+	if (delay > 10)
+		delay = 10;
+
+	INFO("Restarting playback in %u seconds", delay);
+	priv->retry_timeout_id = g_timeout_add_seconds(delay, when_timeout_retry, self);
+}
+
 /*
  * Public methods
  */
@@ -568,49 +698,23 @@ gv_engine_play(GvEngine *self, GvStation *station)
 		return;
 	}
 
-	/* Cleanup error handling */
-	priv->error_count = 0;
-	g_clear_handle_id(&priv->start_playback_timeout_id, g_source_remove);
+	/* Ensure playback is stopped */
+	stop_playback(self);
 
 	/* Set station */
+	INFO("Playing stream '%s'", station_stream_uri);
 	gv_engine_set_station(self, station);
-
-	/* According to the doc:
-	 *
-	 * > State changes to GST_STATE_READY or GST_STATE_NULL never return
-	 * > GST_STATE_CHANGE_ASYNC.
-	 *
-	 * https://gstreamer.freedesktop.org/documentation/gstreamer/gstelement.html#gst_element_set_state
-	 */
-
-	/* Ensure playback is stopped */
-	set_gst_state(priv->playbin, GST_STATE_NULL);
-
-	/* Set the stream uri */
 	g_object_set(priv->playbin, "uri", station_stream_uri, NULL);
 
-	/* Go to the ready stop (not sure it's needed) */
-	set_gst_state(priv->playbin, GST_STATE_READY);
-
-	/* Set gst state to PAUSE, so that the playbin starts buffering data.
-	 * Playback will start as soon as buffering is finished.
-	 */
-	set_gst_state(priv->playbin, GST_STATE_PAUSED);
-	gv_engine_set_state(self, GV_ENGINE_STATE_CONNECTING);
+	/* Start playback */
+	start_playback(self);
 }
 
 void
 gv_engine_stop(GvEngine *self)
 {
-	GvEnginePrivate *priv = self->priv;
-
-	/* Cleanup error handling */
-	priv->error_count = 0;
-	g_clear_handle_id(&priv->start_playback_timeout_id, g_source_remove);
-
-	/* Radical way to stop: set state to NULL */
-	set_gst_state(priv->playbin, GST_STATE_NULL);
-	gv_engine_set_state(self, GV_ENGINE_STATE_STOPPED);
+	/* Stop playback, unset everything */
+	stop_playback(self);
 	gv_engine_unset_streaminfo(self);
 	gv_engine_unset_metadata(self);
 }
@@ -699,49 +803,6 @@ on_playbin_source_setup(GstElement *playbin G_GNUC_UNUSED,
  * GStreamer bus signal handlers
  */
 
-static gboolean
-when_timeout_start_playback(gpointer data)
-{
-	GvEngine *self = GV_ENGINE(data);
-	GvEnginePrivate *priv = self->priv;
-
-	if (self->priv->state != GV_ENGINE_STATE_STOPPED) {
-		set_gst_state(priv->playbin, GST_STATE_NULL);
-		set_gst_state(priv->playbin, GST_STATE_READY);
-		set_gst_state(priv->playbin, GST_STATE_PAUSED);
-		gv_engine_set_state(self, GV_ENGINE_STATE_CONNECTING);
-	}
-
-	priv->start_playback_timeout_id = 0;
-	return G_SOURCE_REMOVE;
-}
-
-static void
-retry_playback(GvEngine *self)
-{
-	GvEnginePrivate *priv = self->priv;
-	guint delay;
-
-	/* We retry playback after there's been a failure of some sort.
-	 * We don't know what kind of failure, and maybe the network is down,
-	 * in such case we don't want to keep retrying in a wild loop. So the
-	 * strategy here is to start retrying with a minimal delay, and increment
-	 * the delay with the failure count.
-	 */
-
-	if (priv->start_playback_timeout_id != 0)
-		return;
-
-	g_assert(priv->error_count > 0);
-	delay = priv->error_count - 1;
-	if (delay > 10)
-		delay = 10;
-
-	INFO("Restarting playback in %u seconds", delay);
-	priv->start_playback_timeout_id =
-		g_timeout_add_seconds(delay, when_timeout_start_playback, self);
-}
-
 static void
 on_bus_message_eos(GstBus *bus G_GNUC_UNUSED, GstMessage *msg G_GNUC_UNUSED, GvEngine *self)
 {
@@ -749,14 +810,12 @@ on_bus_message_eos(GstBus *bus G_GNUC_UNUSED, GstMessage *msg G_GNUC_UNUSED, GvE
 
 	INFO("Gst bus EOS message");
 
-	priv->error_count++;
-
-	/* Stop immediately otherwise gst keeps on spitting errors */
-	set_gst_state(priv->playbin, GST_STATE_NULL);
-
-	/* Restart playback if needed */
-	if (self->priv->state != GV_ENGINE_STATE_STOPPED)
+	if (priv->target_state >= GST_STATE_PAUSED)
+		/* Schedule playback restart */
 		retry_playback(self);
+	else
+		/* Stop gst from spitting errors */
+		stop_playback(self);
 
 	/* Emit an error */
 	//gv_errorable_emit_error(GV_ERRORABLE(self), "%s", _("End of stream"));
@@ -769,8 +828,6 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 	GError *err;
 	gchar *debug;
 
-	priv->error_count++;
-
 	/* Parse message */
 	gst_message_parse_error(msg, &err, &debug);
 
@@ -779,27 +836,35 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 		g_quark_to_string(err->domain), err->code, err->message);
 	WARNING("Gst bus error debug: %s", debug);
 
-	/* Stop playback otherwise gst keeps on spitting errors */
-	set_gst_state(priv->playbin, GST_STATE_NULL);
-
 	/* Here comes the actual effort to handle errors. At the moment there's
 	 * not much to it, we only handle SSL failures.
 	 */
 	if (g_error_matches(err, GST_RESOURCE_ERROR, GST_RESOURCE_ERROR_OPEN_READ)) {
 		const GstStructure *details = NULL;
+
 		gst_message_parse_error_details(msg, &details);
-		if (details && gst_structure_has_field_typed(details, "http-status-code", G_TYPE_UINT)) {
+		if (details == NULL)
+			goto maybe_retry;
+
+		if (gst_structure_has_field_typed(details, "http-status-code", G_TYPE_UINT)) {
 			guint code = 0;
 			gst_structure_get_uint(details, "http-status-code", &code);
-			if (code == SOUP_STATUS_SSL_FAILED)
+			if (code == SOUP_STATUS_SSL_FAILED) {
+				stop_playback(self);
 				g_signal_emit(self, signals[SIGNAL_SSL_FAILURE], 0, err->message, debug);
+				goto cleanup;
+			}
 		}
-	} else {
-		/* When in doubt, retry! */
-		if (self->priv->state != GV_ENGINE_STATE_STOPPED)
-			retry_playback(self);
 	}
 
+maybe_retry:
+	/* Retry unless for some weird reason we're stopped */
+	if (priv->target_state >= GST_STATE_PAUSED)
+		retry_playback(self);
+	else
+		stop_playback(self);
+
+cleanup:
 	/* Cleanup */
 	g_error_free(err);
 	g_free(debug);
@@ -809,17 +874,18 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 
 	/* Here are some gst error messages that I've dealt with so far.
 	 *
-	 * GST_RESOURCE_ERROR: GST_RESOURCE_ERROR_OPEN_READ
+	 * GST_RESOURCE_ERROR: GST_RESOURCE_ERROR_OPEN_READ (5)
 	 *
 	 * Secure connection setup failed.
 	 *
 	 *   The protocol is https, however the server failed to return a valid
 	 *   certificate. Note that souphttpsrc has a 'ssl-strict' property that
-	 *   default to true. Setting it to false might be enough to play the stream.
+	 *   default to true. Setting it to false is enough to play the stream.
 	 *
 	 *   See #128.
 	 *
-	 * GST_RESOURCE_ERROR: GST_RESOURCE_ERROR_NOT_FOUND
+	 *
+	 * GST_RESOURCE_ERROR: GST_RESOURCE_ERROR_NOT_FOUND (3)
 	 *
 	 * Could not resolve server name.
 	 *
@@ -845,6 +911,18 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 	 *
 	 *   Don't remember about this one...
 	 *
+	 *
+	 * GST_RESOURCE_ERROR: GST_RESOURCE_ERROR_SEEK (11)
+	 *
+	 * Server does not support seeking
+	 *
+	 *   It means that gstreamer tried to seek back. It happens for some streams
+	 *   (not all) if the computer is suspended for a while, then resumed. Upon
+	 *   resume, gst tries to seek. Seen that with a mp3 stream.
+	 *
+	 *   To reproduce: suspend the computer then resume.
+	 *
+	 *
 	 * GST_CORE_ERROR: GST_CORE_ERROR_MISSING_PLUGIN
 	 *
 	 * No URI handler implemented for ...
@@ -981,91 +1059,155 @@ on_bus_message_buffering(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *s
 	static gint prev_percent = 0;
 	gint percent = 0;
 
-	/* Handle the buffering message. Some documentation:
-	 * https://gstreamer.freedesktop.org/documentation/gstreamer/gstmessage.html#gst_message_new_buffering
+	/* There are mostly two situtations: either buffering is 100% and we
+	 * want to be playing,  either it's below and the pipeline should be
+	 * paused.
+	 *
+	 * During the initialization phase (when we start playing a stream), we
+	 * expect to receive plenty of buffering messages until the buffer gets
+	 * full. The pipeline is PAUSED during all this phase,  and it's set to
+	 * PLAY only after 100% is reached.
+	 *
+	 * Then, while we play the stream, it's not uncommon (it's even very
+	 * common, from where I stand) to receive buffering messages with a
+	 * buffer value below 100%. In this case, the documentation states very
+	 * clearly that we should PAUSE the pipeline:
+	 *
+	 * * https://gstreamer.freedesktop.org/documentation/playback/playbin.html
+	 *
+	 *   Note that applications should keep/set the pipeline in the PAUSED
+	 *   state when a BUFFERING message is received with a buffer percent
+	 *   value < 100 and set the pipeline back to PLAYING state when a
+	 *   BUFFERING message with a value of 100 percent is received (if
+	 *   PLAYING is the desired state, that is).
+	 *
+	 * * https://gstreamer.freedesktop.org/documentation/gstreamer/gstmessage.html
+	 *   #gst_message_new_buffering
+	 *
+	 *   When percent is < 100 the application should PAUSE a PLAYING
+	 *   pipeline. When percent is 100, the application can set the pipeline
+	 *   (back) to PLAYING.
+	 *
+	 * However, in practice, it doesn't yield the best result.
+	 *
+	 * Setting the pipeline to PAUSE interrupts the sound. In the best case
+	 * it's a very short interruption, the buffer gets back to 100%
+	 * immediately after setting the pipeline to PAUSED (which makes me
+	 * think it's an issue with gstreamer, rather than a real buffering
+	 * issue), but it still creates a glitch that is audible. I see that
+	 * all the time with Radio Nova mp3 streams.
+	 *
+	 * In the worst case, it's a real interruption, like 1 second. I must
+	 * admit that I didn't see that in a while though...
+	 *
+	 * So instead of setting the pipeline to PAUSED, we can just ignore the
+	 * buffering messages during playback. Everything still works, and we
+	 * don't interrupt the sound.
 	 */
 
 	/* Parse message */
 	gst_message_parse_buffering(msg, &percent);
 
-	/* Display buffering steps 20 by 20 */
+	/* We want to know what's going on, without being spammed */
 	if (ABS(percent - prev_percent) > 20) {
 		prev_percent = percent;
 		DEBUG("Buffering (%3u %%)", percent);
 	}
 
-	/* Now, let's react according to our current state */
-	switch (priv->state) {
-	case GV_ENGINE_STATE_STOPPED:
-		/* This shouldn't happen */
-		WARNING("Received 'bus buffering' while stopped");
-		break;
-
-	case GV_ENGINE_STATE_CONNECTING:
-		/* We successfully connected! */
-		gv_engine_set_state(self, GV_ENGINE_STATE_BUFFERING);
-
-		/* NO BREAK HERE!
-		 * This is to handle the (very special) case where the first
-		 * buffering message received is already 100%. I'm not sure this
-		 * can happen, but it doesn't hurt to be ready.
-		 *
-		 * To avoid warnings, the next line could be:
-		 * __attribute__((fallthrough));
-		 *
-		 * However this is gcc-7 only, and I don't know about clang.
-		 * So we use a more portable (and more magic) marker comment.
-		 */
-		// fall through
-
-	case GV_ENGINE_STATE_BUFFERING:
-		/* When buffering complete, start playing */
-		if (percent >= 100) {
-			DEBUG("Buffering complete, starting playback");
-			set_gst_state(priv->playbin, GST_STATE_PLAYING);
-			gv_engine_set_state(self, GV_ENGINE_STATE_PLAYING);
-			priv->error_count = 0;
+	/* Now let's handle the buffering value */
+#ifdef IGNORE_BUFFERING_MESSAGES
+	if (percent >= 100) {
+		if (priv->target_state == GST_STATE_PAUSED) {
+			DEBUG("Buffering complete, setting pipeline to PLAYING");
+			start_playback_for_real(self);
 		}
-		break;
-
-	case GV_ENGINE_STATE_PLAYING:
-		/* In case buffering is < 100%, according to the documentation,
-		 * we should pause. However, more than often, I constantly
-		 * receive 'buffering < 100%' messages. In such cases, following
-		 * the doc and pausing/playing makes constantly cuts the sound.
-		 * While ignoring the messages works just fine, do let's ignore
-		 * for now.
-		 */
-		if (percent < 100) {
-			DEBUG("Buffering < 100%%, ignoring instead of setting to pause");
-			//set_gst_state(priv->playbin, GST_STATE_PAUSED);
-			//gv_engine_set_state(self, GV_ENGINE_STATE_BUFFERING);
-		}
-		break;
-
-	default:
-		WARNING("Unhandled engine state %d", priv->state);
+		priv->buffering = FALSE;
+		prev_percent = percent;
+	} else {
+		if (priv->target_state == GST_STATE_PLAYING)
+			DEBUG("Buffering < 100%%, ignore and keep playing");
+		else
+			priv->buffering = TRUE;
 	}
+#else
+	if (percent >= 100) {
+		if (priv->target_state == GST_STATE_PAUSED) {
+			DEBUG("Buffering complete, setting pipeline to PLAYING");
+			start_playback_for_real(self);
+		} else if (priv->target_state == GST_STATE_PLAYING) {
+			DEBUG("Done buffering, setting pipeline to PLAYING");
+			set_gst_state(priv->playbin, GST_STATE_PLAYING);
+		}
+		priv->buffering = FALSE;
+		prev_percent = percent;
+	} else {
+		if (priv->target_state == GST_STATE_PLAYING && priv->buffering == FALSE) {
+			/* We were not buffering but PLAYING, PAUSE the pipeline */
+			DEBUG("Buffering < 100%%, setting pipeline to PAUSED");
+			set_gst_state(priv->playbin, GST_STATE_PAUSED);
+		}
+		priv->buffering = TRUE;
+	}
+#endif
 }
 
 static void
-on_bus_message_state_changed(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
-			     GvEngine *self G_GNUC_UNUSED)
+on_bus_message_state_changed(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 {
-#ifdef DEBUG_GST_STATE_CHANGES
+	GvEnginePrivate *priv = self->priv;
 	GstState old, new, pending;
 
+	/* Only care about playbin */
+	if (GST_MESSAGE_SRC(msg) != GST_OBJECT_CAST(priv->playbin))
+		return;
+
 	/* Parse message */
 	gst_message_parse_state_changed(msg, &old, &new, &pending);
 
-	/* Just used for debug */
+	/* Some debug */
 	DEBUG("Gst state changed: old: %s, new: %s, pending: %s",
 	      gst_element_state_get_name(old),
 	      gst_element_state_get_name(new),
 	      gst_element_state_get_name(pending));
-#else
-	(void) msg;
-#endif
+
+	/* Update our own state */
+	switch (new) {
+	case GST_STATE_NULL:
+		gv_engine_set_state(self, GV_ENGINE_STATE_STOPPED);
+		break;
+	case GST_STATE_READY:
+		if (priv->target_state >= GST_STATE_PAUSED)
+			gv_engine_set_state(self, GV_ENGINE_STATE_CONNECTING);
+		else
+			gv_engine_set_state(self, GV_ENGINE_STATE_STOPPED);
+		break;
+	case GST_STATE_PAUSED:
+		if (priv->buffering == TRUE)
+			gv_engine_set_state(self, GV_ENGINE_STATE_BUFFERING);
+		else
+			gv_engine_set_state(self, GV_ENGINE_STATE_CONNECTING);
+		break;
+	case GST_STATE_PLAYING:
+		gv_engine_set_state(self, GV_ENGINE_STATE_PLAYING);
+		break;
+	case GST_STATE_VOID_PENDING:
+		/* Can't happen anyway */
+		break;
+	}
+
+	/* Might want to start playback */
+	if (new == GST_STATE_PAUSED && priv->target_state == GST_STATE_PAUSED) {
+		if (priv->buffering == TRUE) {
+			DEBUG("Pipeline is PREROLLED, waiting for buffering to finish");
+		} else {
+			DEBUG("Pipeline is PREROLLED, no buffering, let's start");
+			start_playback_for_real(self);
+		}
+	}
+
+	/* If playing, then it's time to reset the retry counter */
+	if (new == GST_STATE_PLAYING)
+		priv->retry_count = 0;
 }
 
 static void
@@ -1128,10 +1270,10 @@ gv_engine_finalize(GObject *object)
 	TRACE("%p", object);
 
 	/* Remove pending operations */
-	g_clear_handle_id(&priv->start_playback_timeout_id, g_source_remove);
+	g_clear_handle_id(&priv->retry_timeout_id, g_source_remove);
 
-	/* Stop playback */
-	set_gst_state(priv->playbin, GST_STATE_NULL);
+	/* Stop playback, the hard way */
+	gst_element_set_state(priv->playbin, GST_STATE_NULL);
 
 	/* Unref the bus */
 	gst_bus_remove_signal_watch(priv->bus);
