@@ -63,6 +63,7 @@ static GParamSpec *properties[PROP_N];
 
 enum {
 	SIGNAL_LOADED,
+	SIGNAL_EMPTIED,
 	SIGNAL_STATION_ADDED,
 	SIGNAL_STATION_REMOVED,
 	SIGNAL_STATION_MODIFIED,
@@ -805,6 +806,31 @@ gv_station_list_set_property(GObject *object,
  * Public functions
  */
 
+void
+gv_station_list_empty(GvStationList *self)
+{
+	GvStationListPrivate *priv = self->priv;
+	GList *item;
+
+	/* Iterate on station list and disconnect all signal handlers */
+	for (item = priv->stations; item; item = item->next)
+		g_signal_handlers_disconnect_by_data(item->data, self);
+
+	/* Destroy the station list */
+	g_list_free_full(priv->stations, g_object_unref);
+	priv->stations = NULL;
+
+	/* Destroy the shuffled station list */
+	g_list_free_full(priv->shuffled, g_object_unref);
+	priv->shuffled = NULL;
+
+	/* Emit a signal */
+	g_signal_emit(self, signals[SIGNAL_EMPTIED], 0);
+
+	/* Save */
+	gv_station_list_save_delayed(self);
+}
+
 void
 gv_station_list_remove(GvStationList *self, GvStation *station)
 {
@@ -1140,7 +1166,8 @@ gv_station_list_next(GvStationList *self, GvStation *station,
 GvStation *
 gv_station_list_first(GvStationList *self)
 {
-	GList *stations = self->priv->stations;
+	GvStationListPrivate *priv = self->priv;
+	GList *stations = priv->stations;
 
 	if (stations == NULL)
 		return NULL;
@@ -1151,7 +1178,8 @@ gv_station_list_first(GvStationList *self)
 GvStation *
 gv_station_list_last(GvStationList *self)
 {
-	GList *stations = self->priv->stations;
+	GvStationListPrivate *priv = self->priv;
+	GList *stations = priv->stations;
 
 	if (stations == NULL)
 		return NULL;
@@ -1162,7 +1190,8 @@ gv_station_list_last(GvStationList *self)
 GvStation *
 gv_station_list_at(GvStationList *self, guint n)
 {
-	GList *stations = self->priv->stations;
+	GvStationListPrivate *priv = self->priv;
+	GList *stations = priv->stations;
 	GList *item;
 
 	if (stations == NULL)
@@ -1178,7 +1207,8 @@ gv_station_list_at(GvStationList *self, guint n)
 GvStation *
 gv_station_list_find(GvStationList *self, GvStation *station)
 {
-	GList *stations = self->priv->stations;
+	GvStationListPrivate *priv = self->priv;
+	GList *stations = priv->stations;
 	GList *item;
 
 	item = g_list_find(stations, station);
@@ -1189,6 +1219,7 @@ gv_station_list_find(GvStationList *self, GvStation *station)
 GvStation *
 gv_station_list_find_by_name(GvStationList *self, const gchar *name)
 {
+	GvStationListPrivate *priv = self->priv;
 	GList *item;
 
 	/* Ensure station name is valid */
@@ -1202,7 +1233,7 @@ gv_station_list_find_by_name(GvStationList *self, const gchar *name)
 		return NULL;
 
 	/* Iterate on station list */
-	for (item = self->priv->stations; item; item = item->next) {
+	for (item = priv->stations; item; item = item->next) {
 		GvStation *station = item->data;
 		if (!g_strcmp0(name, gv_station_get_name(station)))
 			return station;
@@ -1214,6 +1245,7 @@ gv_station_list_find_by_name(GvStationList *self, const gchar *name)
 GvStation *
 gv_station_list_find_by_uri(GvStationList *self, const gchar *uri)
 {
+	GvStationListPrivate *priv = self->priv;
 	GList *item;
 
 	/* Ensure station name is valid */
@@ -1223,7 +1255,7 @@ gv_station_list_find_by_uri(GvStationList *self, const gchar *uri)
 	}
 
 	/* Iterate on station list */
-	for (item = self->priv->stations; item; item = item->next) {
+	for (item = priv->stations; item; item = item->next) {
 		GvStation *station = item->data;
 		if (!g_strcmp0(uri, gv_station_get_uri(station)))
 			return station;
@@ -1235,6 +1267,7 @@ gv_station_list_find_by_uri(GvStationList *self, const gchar *uri)
 GvStation *
 gv_station_list_find_by_uid(GvStationList *self, const gchar *uid)
 {
+	GvStationListPrivate *priv = self->priv;
 	GList *item;
 
 	/* Ensure station name is valid */
@@ -1244,7 +1277,7 @@ gv_station_list_find_by_uid(GvStationList *self, const gchar *uid)
 	}
 
 	/* Iterate on station list */
-	for (item = self->priv->stations; item; item = item->next) {
+	for (item = priv->stations; item; item = item->next) {
 		GvStation *station = item->data;
 		if (!g_strcmp0(uid, gv_station_get_uid(station)))
 			return station;
@@ -1534,6 +1567,11 @@ gv_station_list_class_init(GvStationListClass *class)
 			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
 			     G_TYPE_NONE, 0);
 
+	signals[SIGNAL_EMPTIED] =
+		g_signal_new("emptied", G_TYPE_FROM_CLASS(class),
+			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
+			     G_TYPE_NONE, 0);
+
 	signals[SIGNAL_STATION_ADDED] =
 		g_signal_new("station-added", G_TYPE_FROM_CLASS(class),
 			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
