@@ -31,6 +31,10 @@
 #include "gv-graphical-application.h"
 #include "options.h"
 
+#if !GLIB_CHECK_VERSION(2, 74, 0)
+#define G_APPLICATION_DEFAULT_FLAGS G_APPLICATION_FLAGS_NONE
+#endif
+
 /*
  * GObject definitions
  */
@@ -53,7 +57,7 @@ gv_graphical_application_new(const gchar *application_id)
 
 	self = g_object_new(GV_TYPE_GRAPHICAL_APPLICATION,
 			    "application-id", application_id,
-			    "flags", G_APPLICATION_FLAGS_NONE,
+			    "flags", G_APPLICATION_DEFAULT_FLAGS,
 			    NULL);
 
 	return G_APPLICATION(self);
