@@ -44,6 +44,7 @@ static const gchar *translators =
 	"Adolfo Jayme Barrientos <fitojb@ubuntu.com> - Spanish (es)\n"
 	"Benages <juanjo@benages.eu> - Spanish (es)\n"
 	"Holman Calderón <halecalderon@gmail.com> - Spanish (es)\n"
+	"Jiri Grönroos <jiri.gronroos@iki.fi> - Finnish (fi)\n"
 	"Étienne Deparis <etienne@depar.is> - French (fr)\n"
 	"Jeannette L <j.lavoie@net-c.ca> - French (fr)\n"
 	"Milo Ivir <mail@milotype.de> - Croatian (hr)\n"
@@ -55,6 +56,7 @@ static const gchar *translators =
 	"Prachi Joshi <josprachi@yahoo.com> - Marathi (mr)\n"
 	"Allan Nordhøy <epost@anotheragency.no> - Norwegian Bokmål (nb_NO)\n"
 	"Heimen Stoffels <vistausss@fastmail.com> - Dutch (nl)\n"
+	"Def Cik <devcik88@gmail.com> - Polish (pl)\n"
 	"Michal Biesiada <blade-14@o2.pl> - Polish (pl)\n"
 	"Fúlvio Alves <fga.fulvio@gmail.com> - Portuguese (Brazil) (pt_BR)\n"
 	"Ssantos <ssantos@web.de> - Portuguese (pt)\n"
@@ -63,8 +65,11 @@ static const gchar *translators =
 	"Алексей Выскубов <viskubov@gmail.com> - Russian (ru)\n"
 	"Иван <nkvdno@mail.ru> - Russian (ru)\n"
 	"Andrej Shadura <andrew@shadura.me> - Slovak (sk)\n"
+	"Marek Ľach <graweeld@googlemail.com> - Slovak (sk)\n"
 	"Akash Rao <akash.rao.ind@gmail.com> - Telugu (te)\n"
-	"Oğuz Ersen <oguzersen@protonmail.com> - Turkish (tr)";
+	"Oğuz Ersen <oguz@ersen.moe> - Turkish (tr)\n"
+	"Oğuz Ersen <oguzersen@protonmail.com> - Turkish (tr)\n"
+	"KE CHENG HENG <ko89022189@gmail.com> - Chinese (Traditional) (zh_Hant)";
 
 void
 gv_show_about_dialog(GtkWindow *parent, const gchar *audio_backend_string,
@@ -84,7 +89,7 @@ gv_show_about_dialog(GtkWindow *parent, const gchar *audio_backend_string,
 			      "authors", authors,
 			      "comments", comments,
 			      "copyright", GV_COPYRIGHT " " GV_AUTHOR_NAME,
-			      "license-type", GTK_LICENSE_GPL_3_0,
+			      "license-type", GTK_LICENSE_GPL_3_0_ONLY,
 			      "logo-icon-name", GV_ICON_NAME,
 			      "translator-credits", translators,
 			      "version", PACKAGE_VERSION,
