@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,11 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 #include <gtk/gtk.h>
 
 #include "base/glib-object-additions.h"
@@ -86,7 +85,6 @@ struct _GvPrefsWindowPrivate {
 	GtkWidget *window_frame;
 	GtkWidget *window_grid;
 	GtkWidget *window_theme_combo;
-	GtkWidget *window_autosize_check;
 	GtkWidget *notif_frame;
 	GtkWidget *notif_grid;
 	GtkWidget *notif_enable_label;
@@ -107,15 +105,13 @@ struct _GvPrefsWindowPrivate {
 	GtkWidget *middle_click_action_combo;
 	GtkWidget *scroll_action_label;
 	GtkWidget *scroll_action_combo;
-	/* Buttons */
-	GtkWidget *close_button;
 };
 
 typedef struct _GvPrefsWindowPrivate GvPrefsWindowPrivate;
 
 struct _GvPrefsWindow {
 	/* Parent instance structure */
-	GtkWindow             parent_instance;
+	GtkWindow parent_instance;
 	/* Private data */
 	GvPrefsWindowPrivate *priv;
 };
@@ -128,7 +124,7 @@ G_DEFINE_TYPE_WITH_PRIVATE(GvPrefsWindow, gv_prefs_window, GTK_TYPE_WINDOW)
 
 static void
 on_pipeline_apply_button_clicked(GtkButton *button G_GNUC_UNUSED,
-                                 GvPrefsWindow *self)
+				 GvPrefsWindow *self)
 {
 	GvPrefsWindowPrivate *priv = self->priv;
 	GtkEntry *pipeline_entry = GTK_ENTRY(priv->pipeline_entry);
@@ -153,36 +149,15 @@ on_pipeline_apply_button_clicked(GtkButton *button G_GNUC_UNUSED,
 	}
 }
 
-static void
-on_close_button_clicked(GtkButton *button G_GNUC_UNUSED, GvPrefsWindow *self)
-{
-	GtkWindow *window = GTK_WINDOW(self);
-
-	gtk_window_close(window);
-}
-
-static gboolean
-on_window_key_press_event(GvPrefsWindow *self, GdkEventKey *event, gpointer data G_GNUC_UNUSED)
-{
-	GtkWindow *window = GTK_WINDOW(self);
-
-	g_assert(event->type == GDK_KEY_PRESS);
-
-	if (event->keyval == GDK_KEY_Escape)
-		gtk_window_close(window);
-
-	return GDK_EVENT_PROPAGATE;
-}
-
 /*
  * GBinding transform functions
  */
 
 static gboolean
 transform_pipeline_string_to(GBinding *binding G_GNUC_UNUSED,
-                             const GValue *from_value,
-                             GValue *to_value,
-                             gpointer user_data G_GNUC_UNUSED)
+			     const GValue *from_value,
+			     GValue *to_value,
+			     gpointer user_data G_GNUC_UNUSED)
 {
 	const gchar *str;
 
@@ -210,9 +185,9 @@ setup_notebook_page_appearance(GtkWidget *vbox)
 	g_return_if_fail(GTK_IS_BOX(vbox));
 
 	g_object_set(vbox,
-	             "margin", GV_UI_WINDOW_BORDER,
-	             "spacing", GV_UI_GROUP_SPACING,
-	             NULL);
+		     "margin", GV_UI_WINDOW_MARGIN,
+		     "spacing", GV_UI_GROUP_SPACING,
+		     NULL);
 }
 
 static void
@@ -236,9 +211,9 @@ setup_section_appearance(GtkWidget *frame, GtkWidget *grid)
 	}
 
 	g_object_set(grid,
-	             "row-spacing", GV_UI_ELEM_SPACING,
-	             "column-spacing", GV_UI_COLUMN_SPACING,
-	             NULL);
+		     "row-spacing", GV_UI_ELEM_SPACING,
+		     "column-spacing", GV_UI_COLUMN_SPACING,
+		     NULL);
 }
 
 static void
@@ -252,10 +227,10 @@ setdown_widget(const gchar *tooltip_text, GtkWidget *widget)
 
 static void
 setup_setting(const gchar *tooltip_text,
-              GtkWidget *label, GtkWidget *widget, const gchar *widget_prop,
-              GObject *obj, const gchar *obj_prop,
-              GBindingTransformFunc transform_to,
-              GBindingTransformFunc transform_from)
+	      GtkWidget *label, GtkWidget *widget, const gchar *widget_prop,
+	      GObject *obj, const gchar *obj_prop,
+	      GBindingTransformFunc transform_to,
+	      GBindingTransformFunc transform_from)
 {
 	/* Tooltip */
 	if (tooltip_text) {
@@ -272,8 +247,8 @@ setup_setting(const gchar *tooltip_text,
 		return;
 
 	g_object_bind_property_full(obj, obj_prop, widget, widget_prop,
-	                            G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE,
-	                            transform_to, transform_from, NULL, NULL);
+				    G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE,
+				    transform_to, transform_from, NULL, NULL);
 }
 
 static void
@@ -301,7 +276,7 @@ setup_feature(const gchar *tooltip_text, GtkWidget *label, GtkWidget *sw, GvFeat
 	 * Order matters, don't mix up source and target here...
 	 */
 	g_object_bind_property(feat, "enabled", sw, "active",
-	                       G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+			       G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
 }
 
 /*
@@ -324,16 +299,16 @@ gv_prefs_window_populate_features(GvPrefsWindow *self)
 	GvPrefsWindowPrivate *priv = self->priv;
 
 	/* Controls */
-	priv->hotkeys_feat        = gv_feat_find("Hotkeys");
-	priv->dbus_native_feat    = gv_feat_find("DBusServerNative");
-	priv->dbus_mpris2_feat    = gv_feat_find("DBusServerMpris2");
+	priv->hotkeys_feat = gv_feat_find("Hotkeys");
+	priv->dbus_native_feat = gv_feat_find("DBusServerNative");
+	priv->dbus_mpris2_feat = gv_feat_find("DBusServerMpris2");
 
 	/* Display */
-	priv->notifications_feat  = gv_feat_find("Notifications");
+	priv->notifications_feat = gv_feat_find("Notifications");
 	priv->console_output_feat = gv_feat_find("ConsoleOutput");
 
 	/* Player */
-	priv->inhibitor_feat      = gv_feat_find("Inhibitor");
+	priv->inhibitor_feat = gv_feat_find("Inhibitor");
 }
 
 static void
@@ -377,7 +352,6 @@ gv_prefs_window_populate_widgets(GvPrefsWindow *self)
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, window_frame);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, window_grid);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, window_theme_combo);
-	GTK_BUILDER_SAVE_WIDGET(builder, priv, window_autosize_check);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, notif_frame);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, notif_grid);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, notif_enable_label);
@@ -400,9 +374,6 @@ gv_prefs_window_populate_widgets(GvPrefsWindow *self)
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, scroll_action_label);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, scroll_action_combo);
 
-	/* Action area */
-	GTK_BUILDER_SAVE_WIDGET(builder, priv, close_button);
-
 	/* Pack that within the window */
 	gtk_container_add(GTK_CONTAINER(self), priv->window_vbox);
 
@@ -414,10 +385,9 @@ static void
 gv_prefs_window_setup_widgets(GvPrefsWindow *self)
 {
 	GvPrefsWindowPrivate *priv = self->priv;
-	GObject *main_window_mgr_obj = G_OBJECT(gv_ui_main_window_manager);
-	GObject *main_window_obj     = G_OBJECT(gv_ui_main_window);
-	GObject *status_icon_obj     = G_OBJECT(gv_ui_status_icon);
-	GObject *player_obj          = G_OBJECT(gv_core_player);
+	GObject *main_window_obj = G_OBJECT(gv_ui_main_window);
+	GObject *status_icon_obj = G_OBJECT(gv_ui_status_icon);
+	GObject *player_obj = G_OBJECT(gv_core_player);
 
 	/*
 	 * Setup settings and features.
@@ -429,109 +399,97 @@ gv_prefs_window_setup_widgets(GvPrefsWindow *self)
 	/* General */
 	if (status_icon_obj == NULL) {
 		setup_setting(_("Action when the close button is clicked."),
-		              NULL,
-		              priv->close_action_combo, "active-id",
-		              main_window_obj, "close-action",
-		              NULL, NULL);
+			      NULL,
+			      priv->close_action_combo, "active-id",
+			      main_window_obj, "close-action",
+			      NULL, NULL);
 	} else {
 		setdown_widget(_("Setting not available in status icon mode."),
-		               priv->application_frame);
+			       priv->application_frame);
 	}
 
 	setup_setting(_("Whether to start playback automatically on startup."),
-	              NULL,
-	              priv->autoplay_check, "active",
-	              player_obj, "autoplay",
-	              NULL, NULL);
+		      NULL,
+		      priv->autoplay_check, "active",
+		      player_obj, "autoplay",
+		      NULL, NULL);
 
 	setup_setting(_("Whether to use a custom output pipeline."),
-	              NULL,
-	              priv->pipeline_check, "active",
-	              player_obj, "pipeline-enabled",
-	              NULL, NULL);
+		      NULL,
+		      priv->pipeline_check, "active",
+		      player_obj, "pipeline-enabled",
+		      NULL, NULL);
 
 	setup_setting(_("The GStreamer output pipeline used for playback. Refer to the"
-	                " online documentation for examples."),
-	              NULL,
-	              priv->pipeline_entry, NULL,
-	              NULL, NULL,
-	              NULL, NULL);
+			" online documentation for examples."),
+		      NULL,
+		      priv->pipeline_entry, NULL,
+		      NULL, NULL,
+		      NULL, NULL);
 
 	g_object_bind_property_full(player_obj, "pipeline-string",
-	                            priv->pipeline_entry, "text",
-	                            G_BINDING_SYNC_CREATE,
-	                            transform_pipeline_string_to,
-	                            NULL, NULL, NULL);
+				    priv->pipeline_entry, "text",
+				    G_BINDING_SYNC_CREATE,
+				    transform_pipeline_string_to,
+				    NULL, NULL, NULL);
 
 	g_signal_connect_object(priv->pipeline_apply_button, "clicked",
-	                        G_CALLBACK(on_pipeline_apply_button_clicked), self, 0);
+				G_CALLBACK(on_pipeline_apply_button_clicked), self, 0);
 
 	setup_feature(_("Prevent the system from going to sleep while playing."),
-	              priv->inhibitor_label,
-	              priv->inhibitor_switch,
-	              priv->inhibitor_feat);
+		      priv->inhibitor_label,
+		      priv->inhibitor_switch,
+		      priv->inhibitor_feat);
 
 	setup_feature(_("Enable the native D-Bus server "
-	                "(needed for the command-line interface)."),
-	              priv->dbus_native_label,
-	              priv->dbus_native_switch,
-	              priv->dbus_native_feat);
+			"(needed for the command-line interface)."),
+		      priv->dbus_native_label,
+		      priv->dbus_native_switch,
+		      priv->dbus_native_feat);
 
 	setup_feature(_("Enable the MPRIS2 D-Bus server."),
-	              priv->dbus_mpris2_label,
-	              priv->dbus_mpris2_switch,
-	              priv->dbus_mpris2_feat);
+		      priv->dbus_mpris2_label,
+		      priv->dbus_mpris2_switch,
+		      priv->dbus_mpris2_feat);
 
 	/* Display */
 	setup_setting(_("Prefer a different variant of the theme (if available)."),
-	              NULL,
-	              priv->window_theme_combo, "active-id",
-	              main_window_obj, "theme-variant",
-	              NULL, NULL);
-
-	if (status_icon_obj == NULL) {
-		setup_setting(_("Automatically adjust the window height when a station "
-		                "is added or removed."),
-		              NULL,
-		              priv->window_autosize_check, "active",
-		              main_window_mgr_obj, "autoset-height",
-		              NULL, NULL);
-	} else {
-		setdown_widget(_("Setting not available in status icon mode."),
-		               priv->window_autosize_check);
-	}
+		      NULL,
+		      priv->window_theme_combo, "active-id",
+		      main_window_obj, "theme-variant",
+		      NULL, NULL);
 
 	setup_feature(_("Show notification when the status changes."),
-	              priv->notif_enable_label,
-	              priv->notif_enable_switch,
-	              priv->notifications_feat);
+		      priv->notif_enable_label,
+		      priv->notif_enable_switch,
+		      priv->notifications_feat);
 
 	setup_feature(_("Display information on the standard output."),
-	              priv->console_output_label,
-	              priv->console_output_switch,
-	              priv->console_output_feat);
+		      priv->console_output_label,
+		      priv->console_output_switch,
+		      priv->console_output_feat);
 
 	/* Controls */
 	setup_feature(_("Bind mutimedia keys (play/pause/stop/previous/next)."),
-	              priv->hotkeys_label,
-	              priv->hotkeys_switch,
-	              priv->hotkeys_feat);
+		      priv->hotkeys_label,
+		      priv->hotkeys_switch,
+		      priv->hotkeys_feat);
 
 	if (status_icon_obj != NULL) {
 		setup_setting(_("Action triggered by a middle click on the status icon."),
-		              priv->middle_click_action_label,
-		              priv->middle_click_action_combo, "active-id",
-		              status_icon_obj, "middle-click-action",
-		              NULL, NULL);
+			      priv->middle_click_action_label,
+			      priv->middle_click_action_combo, "active-id",
+			      status_icon_obj, "middle-click-action",
+			      NULL, NULL);
 
 		setup_setting(_("Action triggered by mouse-scrolling on the status icon."),
-		              priv->scroll_action_label,
-		              priv->scroll_action_combo, "active-id",
-		              status_icon_obj, "scroll-action",
-		              NULL, NULL);
+			      priv->scroll_action_label,
+			      priv->scroll_action_combo, "active-id",
+			      status_icon_obj, "scroll-action",
+			      NULL, NULL);
 	} else {
 		setdown_widget(_("Setting only available in status icon mode."),
-		               priv->mouse_frame);
+			       priv->mouse_frame);
 	}
 
 	/*
@@ -539,11 +497,11 @@ gv_prefs_window_setup_widgets(GvPrefsWindow *self)
 	 */
 
 	g_object_bind_property(priv->pipeline_check, "active",
-	                       priv->pipeline_entry, "sensitive",
-	                       G_BINDING_SYNC_CREATE);
+			       priv->pipeline_entry, "sensitive",
+			       G_BINDING_SYNC_CREATE);
 	g_object_bind_property(priv->pipeline_check, "active",
-	                       priv->pipeline_apply_button, "sensitive",
-	                       G_BINDING_SYNC_CREATE);
+			       priv->pipeline_apply_button, "sensitive",
+			       G_BINDING_SYNC_CREATE);
 }
 
 static void
@@ -553,9 +511,9 @@ gv_prefs_window_setup_appearance(GvPrefsWindow *self)
 
 	/* Window */
 	g_object_set(priv->window_vbox,
-	             "margin", 0,
-	             "spacing", 0,
-	             NULL);
+		     "margin", 0,
+		     "spacing", 0,
+		     NULL);
 
 	/* General */
 	setup_notebook_page_appearance(priv->general_vbox);
@@ -593,7 +551,6 @@ static void
 gv_prefs_window_constructed(GObject *object)
 {
 	GvPrefsWindow *self = GV_PREFS_WINDOW(object);
-	GvPrefsWindowPrivate *priv = self->priv;
 
 	/* Build the window */
 	gv_prefs_window_populate_features(self);
@@ -601,12 +558,6 @@ gv_prefs_window_constructed(GObject *object)
 	gv_prefs_window_setup_widgets(self);
 	gv_prefs_window_setup_appearance(self);
 
-	/* Connect signal handlers */
-	g_signal_connect_object(priv->close_button, "clicked",
-	                        G_CALLBACK(on_close_button_clicked), self, 0);
-	g_signal_connect_object(self, "key_press_event",
-	                        G_CALLBACK(on_window_key_press_event), NULL, 0);
-
 	/* Chain up */
 	G_OBJECT_CHAINUP_CONSTRUCTED(gv_prefs_window, object);
 }
