@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gtk/gtk.h>
@@ -26,8 +25,9 @@
 #include "ui/gtk-additions.h"
 #include "ui/gv-about-dialog.h"
 #include "ui/gv-keyboard-shortcuts-window.h"
-#include "ui/gv-main-window.h"
 #include "ui/gv-main-window-manager.h"
+#include "ui/gv-main-window-standalone.h"
+#include "ui/gv-main-window-status-icon.h"
 #include "ui/gv-prefs-window.h"
 #include "ui/gv-station-dialog.h"
 #include "ui/gv-status-icon.h"
@@ -42,8 +42,8 @@
 
 GSettings *gv_ui_settings;
 
-GvStatusIcon        *gv_ui_status_icon;
-GvMainWindow        *gv_ui_main_window;
+GvStatusIcon *gv_ui_status_icon;
+GvMainWindow *gv_ui_main_window;
 GvMainWindowManager *gv_ui_main_window_manager;
 
 /*
@@ -99,8 +99,8 @@ void
 gv_ui_present_about(void)
 {
 	gv_show_about_dialog(GTK_WINDOW(gv_ui_main_window),
-	                     gv_core_audio_backend_runtime_version_string(),
-	                     gv_ui_toolkit_runtime_version_string());
+			     gv_core_audio_backend_runtime_version_string(),
+			     gv_ui_toolkit_runtime_version_string());
 }
 
 void
@@ -142,7 +142,9 @@ gv_ui_present_add_station(void)
 void
 gv_ui_play_stop(void)
 {
-	gv_main_window_play_stop(gv_ui_main_window);
+	GvPlayer *player = gv_core_player;
+
+	gv_player_toggle(player);
 }
 
 void
@@ -186,7 +188,7 @@ gv_ui_cleanup(void)
 }
 
 void
-gv_ui_init(GApplication *app, GMenuModel *primary_menu, gboolean status_icon_mode)
+gv_ui_init(GApplication *app, gboolean status_icon_mode)
 {
 	GList *item;
 
@@ -206,16 +208,21 @@ gv_ui_init(GApplication *app, GMenuModel *primary_menu, gboolean status_icon_mod
 	gv_ui_settings = gv_get_settings(UI_SCHEMA_ID_SUFFIX);
 	ui_objects = g_list_append(ui_objects, gv_ui_settings);
 
-	gv_ui_main_window = gv_main_window_new(app, primary_menu, status_icon_mode);
-	ui_objects = g_list_append(ui_objects, gv_ui_main_window);
+	if (status_icon_mode == TRUE) {
+		gv_ui_main_window = gv_main_window_status_icon_new(app);
+		ui_objects = g_list_append(ui_objects, gv_ui_main_window);
 
-	gv_ui_main_window_manager = gv_main_window_manager_new(gv_ui_main_window, status_icon_mode);
-	ui_objects = g_list_append(ui_objects, gv_ui_main_window_manager);
-
-	if (status_icon_mode) {
 		gv_ui_status_icon = gv_status_icon_new(GTK_WINDOW(gv_ui_main_window));
 		ui_objects = g_list_append(ui_objects, gv_ui_status_icon);
 	} else {
+		GvMainWindowManager *mgr;
+
+		gv_ui_main_window = gv_main_window_standalone_new(app);
+		ui_objects = g_list_append(ui_objects, gv_ui_main_window);
+
+		mgr = gv_main_window_manager_new(gv_ui_main_window);
+		ui_objects = g_list_append(ui_objects, mgr);
+
 		gv_ui_status_icon = NULL;
 	}
 
